@@ -1,14 +1,11 @@
 import importlib
-from decimal import Decimal
+from contextlib import contextmanager
 
-from sqlalchemy.orm import declarative_base
 from tornado.options import options
 
 sqlalchemy_orm = None
-sqlalchemy_util_compat = None
 try:
     sqlalchemy_orm = importlib.import_module("sqlalchemy.orm")
-    sqlalchemy_util_compat = importlib.import_module("sqlalchemy.util.compat")
 except ImportError as e:
     raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
 
@@ -24,7 +21,7 @@ class SqlAlchemyHelper:
         else:
             self.pool = pool
 
-    @sqlalchemy_util_compat.contextmanager
+    @contextmanager
     def make_session(self, **kwargs):
         db_session = sqlalchemy_orm.scoped_session(sqlalchemy_orm.sessionmaker(bind=self.pool, **kwargs))
         session = db_session()
@@ -70,28 +67,31 @@ def sqlalchemy_paging(Query, limit_number, offset_number):
 def covert_relationship_property(attr, attr_value):
     if attr.__class__.__name__ == 'ColumnProperty':
         return attr_value
-    elif attr.__class__.__name__ == 'RelationshipProperty':
+    elif attr.__class__.__name__ in ['RelationshipProperty', 'Relationship']:
         attrs = []
         for ar, ar_value in attr.mapper.attrs.items():
             if ar_value.__class__.__name__ == 'ColumnProperty' and ar not in attrs:
                 attrs.append(ar)
-        if attr_value.__class__.__name__ == 'InstrumentedList':
+        if attr_value.__class__.__name__ == 'InstrumentedList' or isinstance(attr_value, list):
             new_data = []
             for item in attr_value:
                 info = dict()
                 for ar in attrs:
                     new_attr_value = getattr(item, ar)
-                    if not item.__class__.__name__ == 'RelationshipProperty':
+                    if new_attr_value.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
                         info[ar] = new_attr_value
                     else:
                         info = covert_relationship_property(ar, new_attr_value)
-                new_data.append(info)
+                if info:
+                    new_data.append(info)
             return new_data
         else:
             new_data = dict()
             for column, value in attr.entity.attrs.items():
-                if not value.__class__.__name__ == 'RelationshipProperty':
-                    new_data[column] = getattr(attr_value, column)
+                if value.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
+                    val = getattr(attr_value, column)
+                    if val.__class__.__name__ not in ['RelationshipProperty', 'InstrumentedList']:
+                        new_data[column] = val
             return new_data
     else:
         return attr_value
@@ -107,7 +107,8 @@ def query_set_to_dict(obj):
                 attr_value = getattr(obj, column)
                 value = covert_relationship_property(attr, attr_value)
                 if not value.__class__.__name__ == 'RelationshipProperty':
-                    obj_dict[column] = value
+                    if value:
+                        obj_dict[column] = value
 
         return obj_dict
     elif hasattr(obj, "keys"):
