@@ -1,20 +1,17 @@
-import datetime
 import json
-from decimal import Decimal
-
-from bson import ObjectId
 
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
-        if isinstance(o, ObjectId):
+        object_class_name = o.__class__.__name__
+        if object_class_name == "ObjectId":
             return str(o)
-        elif isinstance(o, datetime.datetime):
+        elif object_class_name == "datetime":
             return str(o)
-        elif isinstance(o, bytes):
+        elif object_class_name == "bytes":
             return str(o, encoding="utf-8")
-        elif isinstance(o, set):
+        elif object_class_name == "set":
             return list(o)
-        elif isinstance(o, Decimal):
+        elif object_class_name == "Decimal":
             return str(o)
         return json.JSONEncoder.default(self, o)
